@@ -14,11 +14,12 @@ from alvin_api_client.model.api_key_status import APIKeyStatus
 from alvin_api_client.model.admin_config import AdminConfig
 from alvin_api_client.model.alter_parse_result import AlterParseResult
 from alvin_api_client.model.alter_type import AlterType
-from alvin_api_client.model.analytics_environment_config import AnalyticsEnvironmentConfig
+from alvin_api_client.model.alvin_description_request import AlvinDescriptionRequest
 from alvin_api_client.model.auth_provider import AuthProvider
 from alvin_api_client.model.bi_platform import BiPlatform
 from alvin_api_client.model.big_query_account_details import BigQueryAccountDetails
 from alvin_api_client.model.big_query_additional_config import BigQueryAdditionalConfig
+from alvin_api_client.model.classification_match_type import ClassificationMatchType
 from alvin_api_client.model.classification_type import ClassificationType
 from alvin_api_client.model.client_auth_config import ClientAuthConfig
 from alvin_api_client.model.client_config import ClientConfig
@@ -71,17 +72,28 @@ from alvin_api_client.model.data_platform_job_step_sub_type import DataPlatformJ
 from alvin_api_client.model.data_platform_job_step_user import DataPlatformJobStepUser
 from alvin_api_client.model.data_platform_job_type import DataPlatformJobType
 from alvin_api_client.model.data_platform_looker_create import DataPlatformLookerCreate
+from alvin_api_client.model.data_platform_mode_create import DataPlatformModeCreate
 from alvin_api_client.model.data_platform_redshift_create import DataPlatformRedshiftCreate
 from alvin_api_client.model.data_platform_snowflake_create import DataPlatformSnowflakeCreate
 from alvin_api_client.model.data_platform_status import DataPlatformStatus
 from alvin_api_client.model.data_platform_tableau_create import DataPlatformTableauCreate
 from alvin_api_client.model.data_platform_type import DataPlatformType
+from alvin_api_client.model.data_taxonomy_classification import DataTaxonomyClassification
 from alvin_api_client.model.drop_parse_result import DropParseResult
 from alvin_api_client.model.drop_type import DropType
 from alvin_api_client.model.element_position import ElementPosition
 from alvin_api_client.model.email_login_request import EmailLoginRequest
+from alvin_api_client.model.entity_graph_connector_edge import EntityGraphConnectorEdge
+from alvin_api_client.model.entity_graph_node import EntityGraphNode
+from alvin_api_client.model.entity_graph_node_connector import EntityGraphNodeConnector
+from alvin_api_client.model.environment_config import EnvironmentConfig
 from alvin_api_client.model.event_type import EventType
 from alvin_api_client.model.exhange_token_request import ExhangeTokenRequest
+from alvin_api_client.model.experience import Experience
+from alvin_api_client.model.experience_data import ExperienceData
+from alvin_api_client.model.experience_status import ExperienceStatus
+from alvin_api_client.model.experience_user import ExperienceUser
+from alvin_api_client.model.experiences_settings import ExperiencesSettings
 from alvin_api_client.model.extracted_simple_column import ExtractedSimpleColumn
 from alvin_api_client.model.extracted_simple_table import ExtractedSimpleTable
 from alvin_api_client.model.filters_response import FiltersResponse
@@ -114,6 +126,7 @@ from alvin_api_client.model.impact_status import ImpactStatus
 from alvin_api_client.model.impact_type import ImpactType
 from alvin_api_client.model.job_entity_id import JobEntityID
 from alvin_api_client.model.job_entity_usage_stats_report import JobEntityUsageStatsReport
+from alvin_api_client.model.job_integration_request import JobIntegrationRequest
 from alvin_api_client.model.job_query_v1_response import JobQueryV1Response
 from alvin_api_client.model.known_column import KnownColumn
 from alvin_api_client.model.known_table import KnownTable
@@ -125,16 +138,20 @@ from alvin_api_client.model.lineage_connection_type import LineageConnectionType
 from alvin_api_client.model.looker_additional_config import LookerAdditionalConfig
 from alvin_api_client.model.looker_credentials import LookerCredentials
 from alvin_api_client.model.looker_query_comment import LookerQueryComment
+from alvin_api_client.model.mode_additional_config import ModeAdditionalConfig
+from alvin_api_client.model.mode_credentials import ModeCredentials
 from alvin_api_client.model.notification import Notification
 from alvin_api_client.model.notification_config import NotificationConfig
 from alvin_api_client.model.notification_provider import NotificationProvider
 from alvin_api_client.model.notification_type import NotificationType
+from alvin_api_client.model.onboarding_level import OnboardingLevel
 from alvin_api_client.model.operator_type import OperatorType
 from alvin_api_client.model.platform_build_data import PlatformBuildData
 from alvin_api_client.model.platform_build_type import PlatformBuildType
 from alvin_api_client.model.position import Position
 from alvin_api_client.model.predefined_filter import PredefinedFilter
-from alvin_api_client.model.product_analytics_config import ProductAnalyticsConfig
+from alvin_api_client.model.processed_lineage_graph_data import ProcessedLineageGraphData
+from alvin_api_client.model.product_config import ProductConfig
 from alvin_api_client.model.query_builder import QueryBuilder
 from alvin_api_client.model.query_comment import QueryComment
 from alvin_api_client.model.query_create_mode import QueryCreateMode
@@ -163,6 +180,11 @@ from alvin_api_client.model.table_merge_match_type import TableMergeMatchType
 from alvin_api_client.model.table_update import TableUpdate
 from alvin_api_client.model.tableau_additional_config import TableauAdditionalConfig
 from alvin_api_client.model.tableau_credentials import TableauCredentials
+from alvin_api_client.model.tag_entity_get import TagEntityGet
+from alvin_api_client.model.tag_entity_request import TagEntityRequest
+from alvin_api_client.model.tag_type import TagType
+from alvin_api_client.model.tag_values import TagValues
+from alvin_api_client.model.taxonomy_classification_config import TaxonomyClassificationConfig
 from alvin_api_client.model.tiny_url_response import TinyURLResponse
 from alvin_api_client.model.token import Token
 from alvin_api_client.model.tree_result_classification import TreeResultClassification
@@ -172,5 +194,6 @@ from alvin_api_client.model.user_get import UserGet
 from alvin_api_client.model.user_name_usage_stat import UserNameUsageStat
 from alvin_api_client.model.user_organization_api_key_request import UserOrganizationAPIKeyRequest
 from alvin_api_client.model.user_organization_api_key_response import UserOrganizationAPIKeyResponse
+from alvin_api_client.model.user_persona import UserPersona
 from alvin_api_client.model.user_role import UserRole
 from alvin_api_client.model.validation_error import ValidationError
